*****************************************************************
*** Replication file for "Relaxing the Constant Economic Vote Restriction" by Laron K. Williams, Mary Stegmaier and Mard Debus.
***
*** Created: 5-19-15
***
*****************************************************************

*** Set up the working directory
*cd ""

use "German Party Approval.dta", clear

*********************************************************************
*** Stationarity tests
***
*** Phillips-Perron: Ho = series contains unit root (non-stationary)
*** Augmented Dickey-Fuller: Ho = series contains unit root (non-stationary)
*********************************************************************
foreach v of varlist cdu_supW spd_supW fdp_supW g_supW {
	di _newline(2) "Following variable is `v' "
	dfuller `v'
	pperron `v'
}

*******************************************************************
****************** Autoregressive Distributed Lag Model ***********
*******************************************************************
sureg (cdu_supW L.cdu_supW L2.cdu_supW cdu_pm L.cdu_pm L2.cdu_pm cdu_pm_honeymoon L.cdu_pm_honeymoon L2.cdu_pm_honeymoon cdu_scandal L.cdu_scandal L2.cdu_scandal spd_surprise L.spd_surprise L2.spd_surprise therm_cduW L.therm_cduW L2.therm_cduW cdu_pidW L.cdu_pidW L2.cdu_pidW retnatW L.retnatW L2.retnatW cdu_pm_retnatW L.cdu_pm_retnatW L2.cdu_pm_retnatW kosovo L.kosovo L2.kosovo fischer L.fischer L2.fischer rwe_affair L.rwe_affair L2.rwe_affair vw_affair L.vw_affair L2.vw_affair plagiarism L.plagiarism L2.plagiarism fukushima L.fukushima L2.fukushima stuttgart21 L.stuttgart21 L2.stuttgart21 Wulff_scandal) /*
*/	(spd_supW L.spd_supW L2.spd_supW spd_pm L.spd_pm L2.spd_pm spd_cp L.spd_cp L2.spd_cp spd_pm_honeymoon L.spd_pm_honeymoon L2.spd_pm_honeymoon spd_cp_honeymoon L.spd_cp_honeymoon L2.spd_cp_honeymoon spd_surprise L.spd_surprise L2.spd_surprise therm_spdW L.therm_spdW L2.therm_spdW spd_pidW L.spd_pidW L2.spd_pidW retnatW L.retnatW L2.retnatW spd_pm_retnatW L.spd_pm_retnatW L2.spd_pm_retnatW spd_cp_retnatW L.spd_cp_retnatW L2.spd_cp_retnatW kosovo L.kosovo L2.kosovo fischer L.fischer L2.fischer rwe_affair L.rwe_affair L2.rwe_affair vw_affair L.vw_affair L2.vw_affair plagiarism L.plagiarism L2.plagiarism fukushima L.fukushima L2.fukushima stuttgart21 L.stuttgart21 L2.stuttgart21 Wulff_scandal) /*
*/	(fdp_supW L.fdp_supW L2.fdp_supW fdp_cp L.fdp_cp L2.fdp_cp fdp_cp_honeymoon L.fdp_cp_honeymoon L2.fdp_cp_honeymoon therm_fdpW L.therm_fdpW L2.therm_fdpW fdp_pidW L.fdp_pidW L2.fdp_pidW retnatW L.retnatW L2.retnatW fdp_cp_retnatW L.fdp_cp_retnatW L2.fdp_cp_retnatW kosovo L.kosovo L2.kosovo fischer L.fischer L2.fischer rwe_affair L.rwe_affair L2.rwe_affair vw_affair L.vw_affair L2.vw_affair plagiarism L.plagiarism L2.plagiarism fukushima L.fukushima L2.fukushima stuttgart21 L.stuttgart21 L2.stuttgart21 Wulff_scandal) /*
*/	(g_supW L.g_supW L2.g_supW g_cp_honeymoon L.g_cp_honeymoon L2.g_cp_honeymoon g_cp L.g_cp L2.g_cp therm_gruW L.therm_gruW L2.therm_gruW g_pidW L.g_pidW L2.g_pidW retnatW L.retnatW L2.retnatW g_cp_retnatW L.g_cp_retnatW L2.g_cp_retnatW kosovo L.kosovo L2.kosovo fischer L.fischer L2.fischer rwe_affair L.rwe_affair L2.rwe_affair vw_affair L.vw_affair L2.vw_affair plagiarism L.plagiarism L2.plagiarism fukushima L.fukushima L2.fukushima stuttgart21 L.stuttgart21 L2.stuttgart21 Wulff_scandal) /*
*/	if tin(1992m1, 2012m12), corr

*******************************************************************
*** Table 2: Seemingly Unrelated Regression (SUR)
*** NOTE: Pared-down model based on ADL
*******************************************************************
sureg (cdu_supW L.cdu_supW L2.cdu_supW cdu_pm L.cdu_pm therm_cduW cdu_pidW retnatW L.retnatW cdu_pm_retnatW L.cdu_pm_retnatW L2.vw_affair ) /*
*/	(spd_supW L.spd_supW L2.spd_supW spd_pm L.spd_pm spd_cp L.spd_cp therm_spdW L.therm_spdW spd_pidW L2.spd_pidW retnatW L.retnatW spd_pm_retnatW L.spd_pm_retnatW spd_cp_retnatW L.spd_cp_retnatW L2.rwe_affair vw_affair plagiarism L.plagiarism fukushima L2.fukushima) /*
*/	(fdp_supW L.fdp_supW L2.fdp_supW fdp_cp therm_fdpW L.therm_fdpW fdp_pidW retnatW fdp_cp_retnatW L.vw_affair) /*
*/	(g_supW L.g_supW L2.g_supW g_cp L.g_cp therm_gruW g_pidW L.g_pidW L2.g_pidW retnatW L.retnatW g_cp_retnatW L.g_cp_retnatW L.fukushima L2.fukushima) /*
*/	if tin(1992m1, 2012m12), corr

* CDU: opposition
lincom [cdu_supW]retnatW, level(90)
lincom [cdu_supW]retnatW + [cdu_supW]L.retnatW, level(90)

* CDU: PM
lincom [cdu_supW]retnatW + (1 * [cdu_supW]cdu_pm_retnatW), level(90)
lincom ([cdu_supW]retnatW + (1 * [cdu_supW]cdu_pm_retnatW)) + ([cdu_supW]L.retnatW + (1 * [cdu_supW]L.cdu_pm_retnatW)), level(90)

* SPD: opposition
lincom [spd_supW]retnatW, level(90)
lincom [spd_supW]retnatW + [spd_supW]L.retnatW, level(90)

* SPD: coalition partner
lincom [spd_supW]retnatW + (1 * [spd_supW]spd_cp_retnatW), level(90)
lincom ([spd_supW]retnatW + (1 * [spd_supW]spd_cp_retnatW)) + ([spd_supW]L.retnatW + (1 * [spd_supW]L.spd_cp_retnatW)), level(90)

* SPD: prime minister
lincom [spd_supW]retnatW + (1 * [spd_supW]spd_pm_retnatW), level(90)
lincom ([spd_supW]retnatW + (1 * [spd_supW]spd_pm_retnatW)) + ([spd_supW]L.retnatW + (1 * [spd_supW]L.spd_pm_retnatW)), level(90)

* FDP: opposition
lincom [fdp_supW]retnatW, level(90)

* FDP: coalition partner
lincom [fdp_supW]retnatW + (1 * [fdp_supW]fdp_cp_retnatW), level(90)

* G: opposition
lincom [g_supW]retnatW, level(90)
lincom [g_supW]retnatW + [g_supW]L.retnatW, level(90)

* G: coalition partner
lincom [g_supW]retnatW + (1 * [g_supW]g_cp_retnatW), level(90)
lincom ([g_supW]retnatW + (1 * [g_supW]g_cp_retnatW)) + ([g_supW]L.retnatW + (1 * [g_supW]L.g_cp_retnatW)), level(90)

*****************************************************************************************
*** Descriptive statistics
*****************************************************************************************
preserve
	keep if e(sample)
	
	sum cdu_supW therm_cduW cdu_pidW retnatW spd_supW therm_spdW spd_pidW fdp_supW therm_fdpW fdp_pidW g_supW therm_gruW g_pidW retnatW
restore


*****************************************************************************************
*** Path Effects
*****************************************************************************************
set seed 648 
estsimp sureg (cdu_supW L.cdu_supW L2.cdu_supW cdu_pm L.cdu_pm therm_cduW cdu_pidW retnatW L.retnatW cdu_pm_retnatW L.cdu_pm_retnatW L2.vw_affair ) /*
*/	(spd_supW L.spd_supW L2.spd_supW spd_pm L.spd_pm spd_cp L.spd_cp therm_spdW L.therm_spdW spd_pidW L2.spd_pidW retnatW L.retnatW spd_pm_retnatW L.spd_pm_retnatW spd_cp_retnatW L.spd_cp_retnatW L2.rwe_affair vw_affair plagiarism L.plagiarism fukushima L2.fukushima) /*
*/	(fdp_supW L.fdp_supW L2.fdp_supW fdp_cp therm_fdpW L.therm_fdpW fdp_pidW retnatW fdp_cp_retnatW L.vw_affair) /*
*/	(g_supW L.g_supW L2.g_supW g_cp L.g_cp therm_gruW g_pidW L.g_pidW L2.g_pidW retnatW L.retnatW g_cp_retnatW L.g_cp_retnatW L.fukushima L2.fukushima) /*
*/	if tin(1992m1, 2012m12), corr

********************************************** CDU/CSU *****************************************
*** CDU/CSU as chancellor
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW 30 L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.cdu_supW 30 L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_1 = c_3 - c_2
qui sum c_d_1
local mn = r(mean)
_pctile c_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2_t1 = r(mean)

qui sum c_3
local cdu_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_2_t1' L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.cdu_supW `cdu_mean_3_t1' L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_2 = c_3 - c_2
qui sum c_d_2
local mn = r(mean)
_pctile c_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2_t2 = r(mean)

qui sum c_3
local cdu_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_2_t2' L2.cdu_supW `cdu_mean_2_t1'
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_3_t2' L2.cdu_supW `cdu_mean_3_t1'
setx retnatW `i' L.retnatW `im1' cdu_pm 1 L.cdu_pm 1  cdu_pm_retnatW `i'*1 L.cdu_pm_retnatW `im1'*1 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_3 = c_3 - c_2
qui sum c_d_3
local mn = r(mean)
_pctile c_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2 = r(mean)

qui sum c_3
local cdu_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop c_d_*


*** CDU/CSU as Opposition party
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW 30 L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.cdu_supW 30 L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_1 = c_3 - c_2
qui sum c_d_1
local mn = r(mean)
_pctile c_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2_t1 = r(mean)

qui sum c_3
local cdu_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_2_t1' L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.cdu_supW `cdu_mean_3_t1' L2.cdu_supW 30
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_2 = c_3 - c_2
qui sum c_d_2
local mn = r(mean)
_pctile c_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2_t2 = r(mean)

qui sum c_3
local cdu_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_2_t2' L2.cdu_supW `cdu_mean_2_t1'
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.cdu_supW `cdu_mean_3_t2' L2.cdu_supW `cdu_mean_3_t1'
setx retnatW `i' L.retnatW `im1' cdu_pm 0 L.cdu_pm 0  cdu_pm_retnatW `i'*0 L.cdu_pm_retnatW `im1'*0 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen c_d_3 = c_3 - c_2
qui sum c_d_3
local mn = r(mean)
_pctile c_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile c_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum c_2 
local cdu_mean_2 = r(mean)

qui sum c_3
local cdu_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop c_d_*



********************************************** SPD *****************************************
*** SPD as PM
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_1 = s_3 - s_2
qui sum s_d_1
local mn = r(mean)
_pctile s_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t1 = r(mean)

qui sum s_3
local spd_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.spd_supW `spd_mean_3_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_2 = s_3 - s_2
qui sum s_d_2
local mn = r(mean)
_pctile s_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t2 = r(mean)

qui sum s_3
local spd_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t2' L2.spd_supW `spd_mean_2_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_3_t2' L2.spd_supW `spd_mean_3_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 1 L.spd_pm 1 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*1 L.spd_pm_retnatW `im1'*1 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_3 = s_3 - s_2
qui sum s_d_3
local mn = r(mean)
_pctile s_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2 = r(mean)

qui sum s_3
local spd_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop s_d_*

*** SPD as Coalition partner
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_1 = s_3 - s_2
qui sum s_d_1
local mn = r(mean)
_pctile s_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t1 = r(mean)

qui sum s_3
local spd_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.spd_supW `spd_mean_3_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_2 = s_3 - s_2
qui sum s_d_2
local mn = r(mean)
_pctile s_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t2 = r(mean)

qui sum s_3
local spd_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t2' L2.spd_supW `spd_mean_2_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_3_t2' L2.spd_supW `spd_mean_3_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 1 L.spd_cp 1 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*1 L.spd_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_3 = s_3 - s_2
qui sum s_d_3
local mn = r(mean)
_pctile s_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2 = r(mean)

qui sum s_3
local spd_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop s_d_*

*** SPD as Opposition party
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.spd_supW 30 L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_1 = s_3 - s_2
qui sum s_d_1
local mn = r(mean)
_pctile s_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t1 = r(mean)

qui sum s_3
local spd_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.spd_supW `spd_mean_3_t1' L2.spd_supW 30
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_2 = s_3 - s_2
qui sum s_d_2
local mn = r(mean)
_pctile s_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2_t2 = r(mean)

qui sum s_3
local spd_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_2_t2' L2.spd_supW `spd_mean_2_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.spd_supW `spd_mean_3_t2' L2.spd_supW `spd_mean_3_t1'
setx retnatW `i' L.retnatW `im1' spd_pm 0 L.spd_pm 0 spd_cp 0 L.spd_cp 0 spd_pm_retnatW `i'*0 L.spd_pm_retnatW `im1'*0 spd_cp_retnatW `i'*0 L.spd_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen s_d_3 = s_3 - s_2
qui sum s_d_3
local mn = r(mean)
_pctile s_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile s_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum s_2 
local spd_mean_2 = r(mean)

qui sum s_3
local spd_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop s_d_*

********************************************** FDP *****************************************
*** FDP as Coalition partner
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW 5 L2.fdp_supW 5
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.fdp_supW 5 L2.fdp_supW 5
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_1 = f_3 - f_2
qui sum f_d_1
local mn = r(mean)
_pctile f_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2_t1 = r(mean)

qui sum f_3
local fdp_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_2_t1' L2.fdp_supW 5
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.fdp_supW `fdp_mean_3_t1' L2.fdp_supW 5
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_2 = f_3 - f_2
qui sum f_d_2
local mn = r(mean)
_pctile f_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2_t2 = r(mean)

qui sum f_3
local fdp_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_2_t2' L2.fdp_supW `fdp_mean_2_t1'
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_3_t2' L2.fdp_supW `fdp_mean_3_t1'
setx retnatW `i' fdp_cp 1 fdp_cp_retnatW `i'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_3 = f_3 - f_2
qui sum f_d_3
local mn = r(mean)
_pctile f_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2 = r(mean)

qui sum f_3
local fdp_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop f_d_*

*** FDP as Opposition party
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW 5 L2.fdp_supW 5
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.fdp_supW 5 L2.fdp_supW 5
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_1 = f_3 - f_2
qui sum f_d_1
local mn = r(mean)
_pctile f_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2_t1 = r(mean)

qui sum f_3
local fdp_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_2_t1' L2.fdp_supW 5
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.fdp_supW `fdp_mean_3_t1' L2.fdp_supW 5
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_2 = f_3 - f_2
qui sum f_d_2
local mn = r(mean)
_pctile f_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2_t2 = r(mean)

qui sum f_3
local fdp_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_2_t2' L2.fdp_supW `fdp_mean_2_t1'
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.fdp_supW `fdp_mean_3_t2' L2.fdp_supW `fdp_mean_3_t1'
setx retnatW `i' fdp_cp 0 fdp_cp_retnatW `i'*0 
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen f_d_3 = f_3 - f_2
qui sum f_d_3
local mn = r(mean)
_pctile f_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile f_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum f_2 
local fdp_mean_2 = r(mean)

qui sum f_3
local fdp_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop f_d_*



********************************************** Greens *****************************************
*** Greens as Coalition partner
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.g_supW 9 L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.g_supW 9 L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen g_d_1 = g_3 - g_2
qui sum g_d_1
local mn = r(mean)
_pctile g_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2_t1 = r(mean)

qui sum g_3
local g_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_2_t1' L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.g_supW `g_mean_3_t1' L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen g_d_2 = g_3 - g_2
qui sum g_d_2
local mn = r(mean)
_pctile g_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2_t2 = r(mean)

qui sum g_3
local g_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_2_t2' L2.g_supW `g_mean_2_t1'
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_3_t2' L2.g_supW `g_mean_3_t1'
setx retnatW `i' L.retnatW `im1'  g_cp 1 L.g_cp 1 g_cp_retnatW `i'*1 L.g_cp_retnatW `im1'*1
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen g_d_3 = g_3 - g_2
qui sum g_d_3
local mn = r(mean)
_pctile g_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2 = r(mean)

qui sum g_3
local g_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop g_d_*

*** Greens as Opposition party
* t = 1
local i = 2
local im1 = 2

setx mean 
setx L.g_supW 9 L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 3
local im1 = 2

setx mean 
setx L.g_supW 9 L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen g_d_1 = g_3 - g_2
qui sum g_d_1
local mn = r(mean)
_pctile g_d_1, p(5 95)
di "Marginal effect at time t = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_1, p(2.5 97.5)
di "Marginal effect at time t = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2_t1 = r(mean)

qui sum g_3
local g_mean_3_t1 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 2
local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_2_t1' L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2) 

local i = 2
local im1 = 3

setx mean 
setx L.g_supW `g_mean_3_t1' L2.g_supW 9
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3) 

gen g_d_2 = g_3 - g_2
qui sum g_d_2
local mn = r(mean)
_pctile g_d_2, p(5 95)
di "Marginal effect at time t+1 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_2, p(2.5 97.5)
di "Marginal effect at time t+1 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2_t2 = r(mean)

qui sum g_3
local g_mean_3_t2 = r(mean)

drop c_2 - g_2 c_3 - g_3

* t = 3
local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_2_t2' L2.g_supW `g_mean_2_t1'
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_2 s_2 f_2 g_2)

local i = 2
local im1 = 2

setx mean 
setx L.g_supW `g_mean_3_t2' L2.g_supW `g_mean_3_t1'
setx retnatW `i' L.retnatW `im1'  g_cp 0 L.g_cp 0 g_cp_retnatW `i'*0 L.g_cp_retnatW `im1'*0
simqi, ev genev(c_3 s_3 f_3 g_3)

gen g_d_3 = g_3 - g_2
qui sum g_d_3
local mn = r(mean)
_pctile g_d_3, p(5 95)
di "Marginal effect at time t+2 = `mn'; 90% confidence interval = [ " r(r1) ", " r(r2) " ]"
_pctile g_d_3, p(2.5 97.5)
di "Marginal effect at time t+2 = `mn'; 95% confidence interval = [ " r(r1) ", " r(r2) " ]"

qui sum g_2 
local g_mean_2 = r(mean)

qui sum g_3
local g_mean_3 = r(mean)

drop c_2 - g_2 c_3 - g_3
drop g_d_*


